@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -87,6 +87,7 @@ class CSASLMod : public CModule {
         CTable Mechanisms;
         Mechanisms.AddColumn(t_s("Mechanism"));
         Mechanisms.AddColumn(t_s("Description"));
+        Mechanisms.SetStyle(CTable::ListStyle);
 
         for (const auto& it : SupportedMechanisms) {
             Mechanisms.AddRow();
@@ -94,6 +95,7 @@ class CSASLMod : public CModule {
             Mechanisms.SetCell(t_s("Description"), it.sDescription.Resolve());
         }
 
+        PutModule("");
         PutModule(t_s("The following mechanisms are available:"));
         PutModule(Mechanisms);
     }
@@ -194,13 +196,22 @@ class CSASLMod : public CModule {
     }
 
     void Authenticate(const CString& sLine) {
+        /* Send blank authenticate for other mechanisms (like EXTERNAL). */
+        CString sAuthLine;
         if (m_Mechanisms.GetCurrent().Equals("PLAIN") && sLine.Equals("+")) {
-            CString sAuthLine = GetNV("username") + '\0' + GetNV("username") +
+            sAuthLine = GetNV("username") + '\0' + GetNV("username") +
                                 '\0' + GetNV("password");
             sAuthLine.Base64Encode();
-            PutIRC("AUTHENTICATE " + sAuthLine);
-        } else {
-            /* Send blank authenticate for other mechanisms (like EXTERNAL). */
+        }
+
+        /* The spec requires authentication data to be sent in chunks */
+        const size_t chunkSize = 400;
+        for (size_t offset = 0; offset < sAuthLine.length(); offset += chunkSize) {
+            size_t size = std::min(chunkSize, sAuthLine.length() - offset);
+            PutIRC("AUTHENTICATE " + sAuthLine.substr(offset, size));
+        }
+        if (sAuthLine.length() % chunkSize == 0) {
+            /* Signal end if we have a multiple of the chunk size */
             PutIRC("AUTHENTICATE +");
         }
     }
