@@ -862,6 +862,9 @@ void CClient::ClearServerDependentCaps() {
 
 template <typename T>
 void CClient::AddBuffer(const T& Message) {
+    if (!m_pNetwork) {
+        return;
+    }
     const CString sTarget = Message.GetTarget();
 
     T Format;
@@ -889,7 +892,7 @@ void CClient::EchoMessage(const CMessage& Message) {
     CMessage EchoedMessage = Message;
     for (CClient* pClient : GetClients()) {
         if (pClient->HasEchoMessage() ||
-            (pClient != this && (m_pNetwork->IsChan(Message.GetParam(0)) ||
+            (pClient != this && ((m_pNetwork && m_pNetwork->IsChan(Message.GetParam(0))) ||
                                  pClient->HasSelfMessage()))) {
             EchoedMessage.SetNick(GetNickMask());
             pClient->PutClient(EchoedMessage);
@@ -898,6 +901,9 @@ void CClient::EchoMessage(const CMessage& Message) {
 }
 
 set<CChan*> CClient::MatchChans(const CString& sPatterns) const {
+    if (!m_pNetwork) {
+        return {};
+    }
     VCString vsPatterns;
     sPatterns.Replace_n(",", " ")
         .Split(" ", vsPatterns, false, "", "", true, true);
