@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -34,7 +34,7 @@ class CIRCNetworkPingTimer : public CCron {
     CIRCNetworkPingTimer(CIRCNetwork* pNetwork)
         : CCron(), m_pNetwork(pNetwork) {
         SetName("CIRCNetworkPingTimer::" +
-                m_pNetwork->GetUser()->GetUserName() + "::" +
+                m_pNetwork->GetUser()->GetUsername() + "::" +
                 m_pNetwork->GetName());
         Start(m_pNetwork->GetUser()->GetPingSlack());
     }
@@ -77,7 +77,7 @@ class CIRCNetworkJoinTimer : public CCron {
     CIRCNetworkJoinTimer(CIRCNetwork* pNetwork)
         : CCron(), m_bDelayed(false), m_pNetwork(pNetwork) {
         SetName("CIRCNetworkJoinTimer::" +
-                m_pNetwork->GetUser()->GetUserName() + "::" +
+                m_pNetwork->GetUser()->GetUsername() + "::" +
                 m_pNetwork->GetName());
         Start(JOIN_FREQUENCY);
     }
@@ -456,6 +456,35 @@ bool CIRCNetwork::ParseConfig(CConfig* pConfig, CString& sError,
             bool bModRet = LoadModule(sModName, sArgs, sNotice, sModRet);
 
             if (!bModRet) {
+                // Q is removed in znc 1.8
+                if (sModName == "q") {
+                    CUtils::PrintError(
+                        "NOTICE: [q] is unavailable, cannot load.");
+                    CUtils::PrintError(
+                        "NOTICE: [q] is removed in this release of ZNC. Please "
+                        "either remove it from your config or install it as a "
+                        "third party module with the same name.");
+                    CUtils::PrintError(
+                        "NOTICE: More info can be found on "
+                        "https://wiki.znc.in/Q");
+                    return false;
+                }
+
+                // Partyline is removed in znc 1.8
+                if (sModName == "partyline") {
+                    CUtils::PrintError(
+                        "NOTICE: [partyline] is unavailable, cannot load.");
+                    CUtils::PrintError(
+                        "NOTICE: [partyline] is removed in this release"
+                        " of ZNC. Please either remove it from your config or "
+                        "install it as a third party module with the same "
+                        "name.");
+                    CUtils::PrintError(
+                        "NOTICE: More info can be found on "
+                        "https://wiki.znc.in/Partyline");
+                    return false;
+                }
+
                 // XXX The awaynick module was retired in 1.6 (still available
                 // as external module)
                 if (sModName == "awaynick") {
@@ -484,8 +513,8 @@ bool CIRCNetwork::ParseConfig(CConfig* pConfig, CString& sError,
     }
 
     pConfig->FindStringVector("server", vsList);
+    CUtils::PrintAction("Adding " + CString(vsList.size()) + " servers");
     for (const CString& sServer : vsList) {
-        CUtils::PrintAction("Adding server [" + sServer + "]");
         CUtils::PrintStatus(AddServer(sServer));
     }
 
@@ -510,7 +539,7 @@ bool CIRCNetwork::ParseConfig(CConfig* pConfig, CString& sError,
 
         if (!pSubConf->empty()) {
             sError = "Unhandled lines in config for User [" +
-                     m_pUser->GetUserName() + "], Network [" + GetName() +
+                     m_pUser->GetUsername() + "], Network [" + GetName() +
                      "], Channel [" + sChanName + "]!";
             CUtils::PrintError(sError);
 
@@ -1289,7 +1318,7 @@ bool CIRCNetwork::Connect() {
     pIRCSock->SetTrustAllCerts(GetTrustAllCerts());
     pIRCSock->SetTrustPKI(GetTrustPKI());
 
-    DEBUG("Connecting user/network [" << m_pUser->GetUserName() << "/"
+    DEBUG("Connecting user/network [" << m_pUser->GetUsername() << "/"
                                       << m_sName << "]");
 
     bool bAbort = false;
@@ -1303,7 +1332,7 @@ bool CIRCNetwork::Connect() {
         return false;
     }
 
-    CString sSockName = "IRC::" + m_pUser->GetUserName() + "::" + m_sName;
+    CString sSockName = "IRC::" + m_pUser->GetUsername() + "::" + m_sName;
     CZNC::Get().GetManager().Connect(pServer->GetName(), pServer->GetPort(),
                                      sSockName, 120, bSSL, GetBindHost(),
                                      pIRCSock);
