@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -234,13 +234,13 @@ CString CModule::GetWebFilesPath() {
 }
 
 bool CModule::LoadRegistry() {
-    // CString sPrefix = (m_pUser) ? m_pUser->GetUserName() : ".global";
+    // CString sPrefix = (m_pUser) ? m_pUser->GetUsername() : ".global";
     return (m_mssRegistry.ReadFromDisk(GetSavePath() + "/.registry") ==
             MCString::MCS_SUCCESS);
 }
 
 bool CModule::SaveRegistry() const {
-    // CString sPrefix = (m_pUser) ? m_pUser->GetUserName() : ".global";
+    // CString sPrefix = (m_pUser) ? m_pUser->GetUsername() : ".global";
     return (m_mssRegistry.WriteToDisk(GetSavePath() + "/.registry", 0600) ==
             MCString::MCS_SUCCESS);
 }
@@ -2019,13 +2019,15 @@ CModCommand::CModCommand(const CString& sCmd, CmdFunc func,
     : m_sCmd(sCmd), m_pFunc(std::move(func)), m_Args(Args), m_Desc(Desc) {}
 
 void CModCommand::InitHelp(CTable& Table) {
+    Table.SetStyle(CTable::ListStyle);
     Table.AddColumn(t_s("Command", "modhelpcmd"));
     Table.AddColumn(t_s("Description", "modhelpcmd"));
 }
 
 void CModCommand::AddHelp(CTable& Table) const {
     Table.AddRow();
-    Table.SetCell(t_s("Command", "modhelpcmd"), GetCommand() + " " + GetArgs());
+    Table.SetCell(t_s("Command", "modhelpcmd"),
+                  GetCommand() + (GetArgs().empty() ? "" : " ") + GetArgs());
     Table.SetCell(t_s("Description", "modhelpcmd"), GetDescription());
 }
 
