@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -330,6 +330,24 @@ TEST_F(IRCSockTest, OnPartMessage) {
     EXPECT_THAT(m_pTestModule->vChannels, ElementsAre(m_pTestChan));
 }
 
+TEST_F(IRCSockTest, StatusModes) {
+    m_pTestSock->ReadLine(
+        ":server 005 user PREFIX=(Yohv)!@%+ :are supported by this server");
+
+    EXPECT_TRUE(m_pTestSock->IsPermMode('Y'));
+    EXPECT_TRUE(m_pTestSock->IsPermMode('o'));
+    EXPECT_TRUE(m_pTestSock->IsPermMode('h'));
+    EXPECT_TRUE(m_pTestSock->IsPermMode('v'));
+
+    m_pTestChan->SetModes("+sp");
+    m_pTestChan->ModeChange("+Y :nick");
+    EXPECT_EQ(m_pTestChan->GetModeString(), "+ps");
+
+    const CNick& pNick = m_pTestChan->GetNicks().at("nick");
+    EXPECT_TRUE(pNick.HasPerm('!'));
+    EXPECT_FALSE(pNick.HasPerm('@'));
+}
+
 TEST_F(IRCSockTest, OnPingMessage) {
     CMessage msg(":server PING :arg");
     m_pTestSock->ReadLine(msg.ToString());
@@ -530,3 +548,13 @@ TEST_F(IRCSockTest, StatusMsg) {
     EXPECT_EQ(m_pTestChan->GetBuffer().GetLine(0, *m_pTestClient),
               ":someone PRIVMSG @#chan :hello ops");
 }
+
+TEST_F(IRCSockTest, ChanMode) {
+    // https://github.com/znc/znc/issues/1684
+    m_pTestSock->ReadLine(
+        ":irc.znc.in 001 me :Welcome to the Internet Relay Network me");
+    m_pTestSock->ReadLine(
+        ":irc.znc.in 005 me CHANMODES=be,f,lj,nti "
+        ":are supported by this server");
+	m_pTestSock->ReadLine(":irc.znc.in 324 me #chan +ntf ");
+}
